@@ -9,7 +9,7 @@
 // Author:      Robin Dunn
 //
 // Created:     13-Jan-2000
-// RCS-ID:      $Id: ScintillaWX.cpp,v 1.83 2005/04/16 01:36:04 RD Exp $
+// RCS-ID:      $Id: ScintillaWX.cpp,v 1.84 2005/05/13 15:14:00 RD Exp $
 // Copyright:   (c) 2000 by Total Control Software
 // Licence:     wxWindows license
 /////////////////////////////////////////////////////////////////////////////
@@ -851,7 +851,7 @@ int  ScintillaWX::DoKeyDown(const wxKeyEvent& evt, bool* consumed)
          ctrl  = evt.ControlDown(),
          alt   = evt.AltDown();
 
-    if (ctrl && key >= 1 && key <= 26)
+    if (ctrl && key >= 1 && key <= 26 && key != WXK_BACK)
         key += 'A' - 1;
 
     switch (key) {
