@@ -4,7 +4,7 @@
 // Author:      David Webster
 // Modified by:
 // Created:     10/12/99
-// RCS-ID:      $Id: window.h,v 1.54 2005/02/10 10:49:33 ABX Exp $
+// RCS-ID:      $Id: window.h,v 1.55 2005/04/27 01:12:00 DW Exp $
 // Copyright:   (c) David Webster
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -234,7 +234,7 @@ public:
 
     // returns true if the window has been created
     bool         OS2Create( PSZ            zClass
-                           ,const char*    zTitle
+                           ,const wxChar*  zTitle
                            ,WXDWORD        dwStyle
                            ,const wxPoint& rPos
                            ,const wxSize&  rSize
