@@ -4,7 +4,7 @@
 // Author:      Vadim Zeitlin
 // Modified by:
 // Created:     04/01/98
-// RCS-ID:      $Id: dnd.cpp,v 1.97 2004/12/19 14:41:45 VZ Exp $
+// RCS-ID:      $Id: dnd.cpp,v 1.98 2005/05/31 09:19:22 JS Exp $
 // Copyright:
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -1730,7 +1730,7 @@ void DnDShapeFrame::OnDrag(wxMouseEvent& event)
     {
         default:
         case wxDragError:
-            wxLogError(wxT("An error occured during drag and drop operation"));
+            wxLogError(wxT("An error occurred during drag and drop operation"));
             break;
 
         case wxDragNone:
