@@ -3,7 +3,7 @@
 // Purpose:     TextCtrl wxWidgets sample
 // Author:      Robert Roebling
 // Modified by:
-// RCS-ID:      $Id: text.cpp,v 1.80 2005/02/26 14:40:39 JS Exp $
+// RCS-ID:      $Id: text.cpp,v 1.81 2005/06/02 12:04:38 JS Exp $
 // Copyright:   (c) Robert Roebling, Julian Smart, Vadim Zeitlin
 // Licence:     wxWindows license
 /////////////////////////////////////////////////////////////////////////////
@@ -328,9 +328,9 @@ IMPLEMENT_APP(MyApp)
 
 enum
 {
-    TEXT_QUIT = 100,
-    TEXT_ABOUT,
-    TEXT_LOAD,
+    TEXT_QUIT = wxID_EXIT,
+    TEXT_ABOUT = wxID_ABOUT,
+    TEXT_LOAD = 101,
     TEXT_SAVE,
     TEXT_CLEAR,
     TEXT_RICH_TEXT_TEST,
