@@ -2,7 +2,7 @@
 // Name:        app.cpp
 // Purpose:
 // Author:      Robert Roebling
-// Id:          $Id: app.cpp,v 1.209 2005/04/13 20:05:57 MW Exp $
+// Id:          $Id: app.cpp,v 1.211 2005/05/30 09:08:49 JS Exp $
 // Copyright:   (c) 1998 Robert Roebling, Julian Smart
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -136,9 +136,11 @@ bool wxApp::Yield(bool onlyIfNeeded)
     // never finish.
     wxTheApp->RemoveIdleTag();
 
+#if wxUSE_LOG
     // disable log flushing from here because a call to wxYield() shouldn't
     // normally result in message boxes popping up &c
     wxLog::Suspend();
+#endif
 
     while (gtk_events_pending())
         gtk_main_iteration();
@@ -151,8 +153,10 @@ bool wxApp::Yield(bool onlyIfNeeded)
     // return value of Processidle().
     ProcessIdle();
 
+#if wxUSE_LOG
     // let the logs be flashed again
     wxLog::Resume();
+#endif
 
     wxIsInsideYield = FALSE;
 
@@ -612,6 +616,8 @@ bool wxApp::Initialize(int& argc, wxChar **argv)
     // (1) this variable exists for the sole purpose of specifying the encoding
     //     of the filenames for GTK+ programs, so use it if it is set
     wxString encName(wxGetenv(_T("G_FILENAME_ENCODING")));
+    if (encName == _T("@locale"))
+        encName.clear();
     encName.MakeUpper();
 #if wxUSE_INTL        
     if (encName.empty())
