@@ -4,7 +4,7 @@
 // Author:      Stefan Csomor
 // Modified by:
 // Created:     24.09.01
-// RCS-ID:      $Id: toplevel.cpp,v 1.145 2005/04/15 07:22:33 JS Exp $
+// RCS-ID:      $Id: toplevel.cpp,v 1.149 2005/05/31 09:20:20 JS Exp $
 // Copyright:   (c) 2001-2004 Stefan Csomor
 // License:     wxWindows licence
 ///////////////////////////////////////////////////////////////////////////////
@@ -111,7 +111,7 @@ static pascal OSStatus TextInputEventHandler( EventHandlerCallRef handler , Even
     OSStatus result = eventNotHandledErr ;
 
     wxWindow* focus = wxWindow::FindFocus() ;
-    char charCode ;
+    unsigned char charCode ;
     UInt32 keyCode ;
     UInt32 modifiers ;
     Point point ;
@@ -167,7 +167,7 @@ static pascal OSStatus KeyboardEventHandler( EventHandlerCallRef handler , Event
     if ( focus == NULL )
         return result ;
         
-    char charCode ;
+    unsigned char charCode ;
     wxChar uniChar = 0 ; 
     UInt32 keyCode ;
     UInt32 modifiers ;
@@ -976,8 +976,18 @@ wxTopLevelWindowMac::~wxTopLevelWindowMac()
 
 void wxTopLevelWindowMac::Maximize(bool maximize)
 {
+    // TODO Check, is this still necessary
+#if 0
     wxMacPortStateHelper help( (GrafPtr) GetWindowPort( (WindowRef) m_macWindow) ) ;
     wxMacWindowClipper clip (this);
+#endif
+    if ( !IsWindowInStandardState( (WindowRef)m_macWindow, NULL, NULL) ) 
+    {
+        Rect rect;
+        GetWindowBounds((WindowRef)m_macWindow, kWindowGlobalPortRgn, &rect);
+        SetWindowIdealUserState((WindowRef)m_macWindow, &rect);
+        SetWindowUserState((WindowRef)m_macWindow, &rect);
+    }
     ZoomWindow( (WindowRef)m_macWindow , maximize ? inZoomOut : inZoomIn , false ) ;
 }
 
@@ -999,7 +1009,10 @@ bool wxTopLevelWindowMac::IsIconized() const
 
 void wxTopLevelWindowMac::Restore()
 {
-    // not available on mac
+    if ( IsMaximized() ) 
+        Maximize(false);
+    else if ( IsIconized() ) 
+        Iconize(false);
 }
 
 // ----------------------------------------------------------------------------
@@ -1096,6 +1109,7 @@ void  wxTopLevelWindowMac::MacCreateRealWindow( const wxString& title,
     else if ( HasFlag( wxCAPTION ) )
     {
         wclass = kDocumentWindowClass ;
+        attr |= kWindowInWindowMenuAttribute ;
     }
 #if defined( __WXMAC__ ) && TARGET_API_MAC_OSX && ( MAC_OS_X_VERSION_MAX_ALLOWED >= MAC_OS_X_VERSION_10_2 )
     else if ( HasFlag( wxFRAME_DRAWER ) )
@@ -1183,7 +1197,7 @@ void  wxTopLevelWindowMac::MacCreateRealWindow( const wxString& title,
     if ( m_macUsesCompositing )
     {
         // There is a bug in 10.2.X for ::GetRootControl returning the window view instead of 
-        // the content view, so we have to retrieve it explicitely
+        // the content view, so we have to retrieve it explicitly
         HIViewFindByID( HIViewGetRoot( (WindowRef) m_macWindow ) , kHIViewWindowContentID , 
             m_peer->GetControlRefAddr() ) ;
         if ( !m_peer->Ok() )
