@@ -4,7 +4,7 @@
 // Author:      Vadim Zeitlin
 // Modified by:
 // Created:     11.06.98
-// RCS-ID:      $Id: notebook.cpp,v 1.145 2005/04/19 08:47:36 JS Exp $
+// RCS-ID:      $Id: notebook.cpp,v 1.155 2005/05/30 11:23:27 JS Exp $
 // Copyright:   (c) 1998 Vadim Zeitlin <zeitlin@dptmaths.ens-cachan.fr>
 // Licence:     wxWindows licence
 ///////////////////////////////////////////////////////////////////////////////
@@ -57,15 +57,14 @@
 // check that the page index is valid
 #define IS_VALID_PAGE(nPage) ((nPage) < GetPageCount())
 
-// hide the ugly cast
-#define m_hwnd    (HWND)GetHWND()
-
+// you can set USE_NOTEBOOK_ANTIFLICKER to 0 for desktop Windows versions too
+// to disable code whih results in flicker-less notebook redrawing at the
+// expense of some extra GDI resource consumption
 #ifdef __WXWINCE__
-#define USE_NOTEBOOK_ANTIFLICKER    0
+    // notebooks are never resized under CE anyhow
+    #define USE_NOTEBOOK_ANTIFLICKER    0
 #else
-// Set this to 1 to compile anti-flicker code, which creates a potentially
-// large bitmap for every paint event
-#define USE_NOTEBOOK_ANTIFLICKER    0
+    #define USE_NOTEBOOK_ANTIFLICKER    1
 #endif
 
 // ----------------------------------------------------------------------------
@@ -85,6 +84,17 @@
     #define TCS_BOTTOM      TCS_RIGHT
 #endif
 
+// ----------------------------------------------------------------------------
+// global variables
+// ----------------------------------------------------------------------------
+
+#if USE_NOTEBOOK_ANTIFLICKER
+
+// the pointer to standard spin button wnd proc
+static WXFARPROC gs_wndprocNotebookSpinBtn = (WXFARPROC)NULL;
+
+#endif // USE_NOTEBOOK_ANTIFLICKER
+
 // ----------------------------------------------------------------------------
 // event table
 // ----------------------------------------------------------------------------
@@ -97,13 +107,14 @@ DEFINE_EVENT_TYPE(wxEVT_COMMAND_NOTEBOOK_PAGE_CHANGED)
 DEFINE_EVENT_TYPE(wxEVT_COMMAND_NOTEBOOK_PAGE_CHANGING)
 
 BEGIN_EVENT_TABLE(wxNotebook, wxControl)
-#if USE_NOTEBOOK_ANTIFLICKER
-    EVT_ERASE_BACKGROUND(wxNotebook::OnEraseBackground)
-    EVT_PAINT(wxNotebook::OnPaint)
-#endif        
     EVT_NOTEBOOK_PAGE_CHANGED(-1, wxNotebook::OnSelChange)
     EVT_SIZE(wxNotebook::OnSize)
     EVT_NAVIGATION_KEY(wxNotebook::OnNavigationKey)
+
+#if USE_NOTEBOOK_ANTIFLICKER
+    EVT_ERASE_BACKGROUND(wxNotebook::OnEraseBackground)
+    EVT_PAINT(wxNotebook::OnPaint)
+#endif // USE_NOTEBOOK_ANTIFLICKER
 END_EVENT_TABLE()
 
 #if wxUSE_EXTENDED_RTTI
@@ -188,25 +199,6 @@ IMPLEMENT_DYNAMIC_CLASS(wxNotebookPageInfo, wxObject )
 #endif
 IMPLEMENT_DYNAMIC_CLASS(wxNotebookEvent, wxNotifyEvent)
 
-// ---------------------------------------------------------------------------
-// private functions
-// ---------------------------------------------------------------------------
-
-#if USE_NOTEBOOK_ANTIFLICKER
-// wnd proc for the spin button
-LRESULT APIENTRY _EXPORT wxNotebookSpinBtnWndProc(HWND hWnd,
-                                                  UINT message,
-                                                  WPARAM wParam,
-                                                  LPARAM lParam);
-
-// ---------------------------------------------------------------------------
-// global vars
-// ---------------------------------------------------------------------------
-
-// the pointer to standard spin button wnd proc
-static WXFARPROC s_wndprocNotebookSpinBtn = (WXFARPROC)NULL;
-#endif
-
 // ============================================================================
 // implementation
 // ============================================================================
@@ -237,6 +229,10 @@ void wxNotebook::Init()
 #if wxUSE_UXTHEME
   m_hbrBackground = NULL;
 #endif // wxUSE_UXTHEME
+
+#if USE_NOTEBOOK_ANTIFLICKER
+  m_hasSubclassedUpdown = false;
+#endif // USE_NOTEBOOK_ANTIFLICKER
 }
 
 // default for dynamic class
@@ -345,7 +341,7 @@ bool wxNotebook::Create(wxWindow *parent,
 #if defined(__POCKETPC__) || defined(__SMARTPHONE__)
     if (HasFlag(wxNB_FLAT))
     {
-        SendMessage(m_hwnd, CCM_SETVERSION, COMCTL32_VERSION, 0);
+        SendMessage(GetHwnd(), CCM_SETVERSION, COMCTL32_VERSION, 0);
         if (!m_hasBgCol)
             SetBackgroundColour(*wxWHITE);
     }
@@ -397,14 +393,14 @@ wxNotebook::~wxNotebook()
 size_t wxNotebook::GetPageCount() const
 {
   // consistency check
-  wxASSERT( (int)m_pages.Count() == TabCtrl_GetItemCount(m_hwnd) );
+  wxASSERT( (int)m_pages.Count() == TabCtrl_GetItemCount(GetHwnd()) );
 
   return m_pages.Count();
 }
 
 int wxNotebook::GetRowCount() const
 {
-  return TabCtrl_GetRowCount(m_hwnd);
+  return TabCtrl_GetRowCount(GetHwnd());
 }
 
 int wxNotebook::SetSelection(size_t nPage)
@@ -423,7 +419,7 @@ int wxNotebook::SetSelection(size_t nPage)
       event.SetEventType(wxEVT_COMMAND_NOTEBOOK_PAGE_CHANGED);
       (void)GetEventHandler()->ProcessEvent(event);
 
-      TabCtrl_SetCurSel(m_hwnd, nPage);
+      TabCtrl_SetCurSel(GetHwnd(), nPage);
     }
   }
 
@@ -438,7 +434,7 @@ bool wxNotebook::SetPageText(size_t nPage, const wxString& strText)
   tcItem.mask = TCIF_TEXT;
   tcItem.pszText = (wxChar *)strText.c_str();
 
-  return TabCtrl_SetItem(m_hwnd, nPage, &tcItem) != 0;
+  return TabCtrl_SetItem(GetHwnd(), nPage, &tcItem) != 0;
 }
 
 wxString wxNotebook::GetPageText(size_t nPage) const
@@ -452,7 +448,7 @@ wxString wxNotebook::GetPageText(size_t nPage) const
   tcItem.cchTextMax = WXSIZEOF(buf);
 
   wxString str;
-  if ( TabCtrl_GetItem(m_hwnd, nPage, &tcItem) )
+  if ( TabCtrl_GetItem(GetHwnd(), nPage, &tcItem) )
     str = tcItem.pszText;
 
   return str;
@@ -465,7 +461,7 @@ int wxNotebook::GetPageImage(size_t nPage) const
   TC_ITEM tcItem;
   tcItem.mask = TCIF_IMAGE;
 
-  return TabCtrl_GetItem(m_hwnd, nPage, &tcItem) ? tcItem.iImage : -1;
+  return TabCtrl_GetItem(GetHwnd(), nPage, &tcItem) ? tcItem.iImage : -1;
 }
 
 bool wxNotebook::SetPageImage(size_t nPage, int nImage)
@@ -476,7 +472,7 @@ bool wxNotebook::SetPageImage(size_t nPage, int nImage)
   tcItem.mask = TCIF_IMAGE;
   tcItem.iImage = nImage;
 
-  return TabCtrl_SetItem(m_hwnd, nPage, &tcItem) != 0;
+  return TabCtrl_SetItem(GetHwnd(), nPage, &tcItem) != 0;
 }
 
 void wxNotebook::SetImageList(wxImageList* imageList)
@@ -485,7 +481,7 @@ void wxNotebook::SetImageList(wxImageList* imageList)
 
   if ( imageList )
   {
-    TabCtrl_SetImageList(m_hwnd, (HIMAGELIST)imageList->GetHIMAGELIST());
+    TabCtrl_SetImageList(GetHwnd(), (HIMAGELIST)imageList->GetHIMAGELIST());
   }
 }
 
@@ -501,14 +497,14 @@ wxRect wxNotebook::GetPageSize() const
     ::GetClientRect(GetHwnd(), &rc);
 
     // This check is to work around a bug in TabCtrl_AdjustRect which will
-    // cause a crash on win2k, or on XP with themes disabled, if the
-    // wxNB_MULTILINE style is used and the rectangle is very small, (such as
-    // when the notebook is first created.)  The value of 20 is just
-    // arbitrarily chosen, if there is a better way to determine this value
-    // then please do so.  --RD
-    if ( !HasFlag(wxNB_MULTILINE) || (rc.right > 20 && rc.bottom > 20) )
+    // cause a crash on win2k or on XP with themes disabled if either
+    // wxNB_MULTILINE is used or tabs are placed on a side, if the rectangle
+    // is too small.
+    //
+    // The value of 20 is chosen arbitrarily but seems to work
+    if ( rc.right > 20 && rc.bottom > 20 )
     {
-        TabCtrl_AdjustRect(m_hwnd, false, &rc);
+        TabCtrl_AdjustRect(GetHwnd(), false, &rc);
 
         wxCopyRECTToRect(rc, r);
     }
@@ -592,7 +588,7 @@ wxNotebookPage *wxNotebook::DoRemovePage(size_t nPage)
     if ( !pageRemoved )
         return NULL;
 
-    TabCtrl_DeleteItem(m_hwnd, nPage);
+    TabCtrl_DeleteItem(GetHwnd(), nPage);
 
     if ( m_pages.IsEmpty() )
     {
@@ -601,7 +597,7 @@ wxNotebookPage *wxNotebook::DoRemovePage(size_t nPage)
     }
     else // notebook still not empty
     {
-        int selNew = TabCtrl_GetCurSel(m_hwnd);
+        int selNew = TabCtrl_GetCurSel(GetHwnd());
         if (selNew != -1)
         {
             // No selection change, just refresh the current selection.
@@ -645,7 +641,7 @@ bool wxNotebook::DeleteAllPages()
 
   m_pages.Clear();
 
-  TabCtrl_DeleteAllItems(m_hwnd);
+  TabCtrl_DeleteAllItems(GetHwnd());
 
   m_nSelection = -1;
 
@@ -704,7 +700,7 @@ bool wxNotebook::InsertPage(size_t nPage,
     AdjustPageSize(pPage);
 
     // finally do insert it
-    if ( TabCtrl_InsertItem(m_hwnd, nPage, &tcItem) == -1 )
+    if ( TabCtrl_InsertItem(GetHwnd(), nPage, &tcItem) == -1 )
     {
         wxLogError(wxT("Can't create the notebook page '%s'."), strText.c_str());
 
@@ -774,6 +770,57 @@ int wxNotebook::HitTest(const wxPoint& pt, long *flags) const
     return item;
 }
 
+// ----------------------------------------------------------------------------
+// flicker-less notebook redraw
+// ----------------------------------------------------------------------------
+
+#if USE_NOTEBOOK_ANTIFLICKER
+
+// wnd proc for the spin button
+LRESULT APIENTRY _EXPORT wxNotebookSpinBtnWndProc(HWND hwnd,
+                                                  UINT message,
+                                                  WPARAM wParam,
+                                                  LPARAM lParam)
+{
+    if ( message == WM_ERASEBKGND )
+        return 0;
+
+    return ::CallWindowProc(CASTWNDPROC gs_wndprocNotebookSpinBtn,
+                            hwnd, message, wParam, lParam);
+}
+
+
+void wxNotebook::OnEraseBackground(wxEraseEvent& WXUNUSED(event))
+{
+    // do nothing here
+}
+
+void wxNotebook::OnPaint(wxPaintEvent& WXUNUSED(event))
+{
+    wxPaintDC dc(this);
+    wxMemoryDC memdc;
+    RECT rc;
+    ::GetClientRect(GetHwnd(), &rc);
+    wxBitmap bmp(rc.right, rc.bottom);
+    memdc.SelectObject(bmp);
+
+    // if there is no special brush just use the solid background colour
+    HBRUSH hbr = (HBRUSH)m_hbrBackground;
+    wxBrush brush;
+    if ( !hbr )
+    {
+        brush = wxBrush(GetBackgroundColour());
+        hbr = GetHbrushOf(brush);
+    }
+
+    ::FillRect(GetHdcOf(memdc), &rc, hbr);
+
+    MSWDefWindowProc(WM_PAINT, (WPARAM)memdc.GetHDC(), 0);
+
+    dc.Blit(0, 0, rc.right, rc.bottom, &memdc, 0, 0);
+}
+
+#endif // USE_NOTEBOOK_ANTIFLICKER
 
 // ----------------------------------------------------------------------------
 // wxNotebook callbacks
@@ -797,22 +844,22 @@ void wxNotebook::OnSize(wxSizeEvent& event)
         // This needs to be reconciled with the RefreshRect calls
         // at the end of this function, which weren't enough to prevent
         // the droppings.
-        
+
         wxSize sz = GetClientSize();
 
         // Refresh right side
         wxRect rect(sz.x-4, 0, 4, sz.y);
         RefreshRect(rect);
-        
+
         // Refresh bottom side
         rect = wxRect(0, sz.y-4, sz.x, 4);
         RefreshRect(rect);
-        
+
         // Refresh left side
         rect = wxRect(0, 0, 4, sz.y);
         RefreshRect(rect);
     }
-#endif
+#endif // !__WXWINCE__
 
     // fit all the notebook pages to the tab control's display area
 
@@ -852,7 +899,7 @@ void wxNotebook::OnSize(wxSizeEvent& event)
     UpdateBgBrush();
 #endif // wxUSE_UXTHEME
 
-    TabCtrl_AdjustRect(m_hwnd, false, &rc);
+    TabCtrl_AdjustRect(GetHwnd(), false, &rc);
 
     int width = rc.right - rc.left,
         height = rc.bottom - rc.top;
@@ -875,6 +922,34 @@ void wxNotebook::OnSize(wxSizeEvent& event)
                     false);
     }
 
+#if USE_NOTEBOOK_ANTIFLICKER
+    // subclass the spin control used by the notebook to scroll pages to
+    // prevent it from flickering on resize
+    if ( !m_hasSubclassedUpdown )
+    {
+        // iterate over all child windows to find spin button
+        for ( HWND child = ::GetWindow(GetHwnd(), GW_CHILD);
+              child;
+              child = ::GetWindow(child, GW_HWNDNEXT) )
+        {
+            wxWindow *childWindow = wxFindWinFromHandle((WXHWND)child);
+
+            // see if it exists, if no wxWindow found then assume it's the spin
+            // btn
+            if ( !childWindow )
+            {
+                // subclass the spin button to override WM_ERASEBKGND
+                if ( !gs_wndprocNotebookSpinBtn )
+                    gs_wndprocNotebookSpinBtn = (WXFARPROC)wxGetWindowProc(child);
+
+                wxSetWindowProc(child, wxNotebookSpinBtnWndProc);
+                m_hasSubclassedUpdown = true;
+                break;
+            }
+        }
+    }
+#endif // USE_NOTEBOOK_ANTIFLICKER
+
     event.Skip();
 }
 
@@ -892,18 +967,14 @@ void wxNotebook::OnSelChange(wxNotebookEvent& event)
       {
         wxNotebookPage *pPage = m_pages[sel];
         pPage->Show(true);
-        pPage->SetFocus();
-
-        // If the newly focused window is not a child of the new page,
-        // SetFocus was not successful and the notebook itself should be
-        // focused
-        wxWindow *currentFocus = FindFocus();
-        wxWindow *startFocus = currentFocus;
-        while ( currentFocus && currentFocus != pPage && currentFocus != this )
-            currentFocus = currentFocus->GetParent();
-
-        if ( startFocus == pPage || currentFocus != pPage )
-            SetFocus();
+        
+        // As per bug report:
+        // http://sourceforge.net/tracker/index.php?func=detail&aid=1150659&group_id=9863&atid=109863,
+        // we should not set the page focus (and thereby the focus for
+        // a child window) since it erroneously selects radio button controls and also
+        // breaks keyboard handling for a notebook's scroll buttons. So
+        // we always focus the notebook and not the page.
+        SetFocus();
 
       }
       else // no pages in the notebook, give the focus to itself
@@ -928,7 +999,7 @@ bool wxNotebook::MSWTranslateMessage(WXMSG *wxmsg)
     // intercept SHIFT+TAB. This goes to the parent of the notebook which will
     // process it.
     if ( msg->message == WM_KEYDOWN && msg->wParam == VK_TAB &&
-            msg->hwnd == m_hwnd &&
+            msg->hwnd == GetHwnd() &&
                 (wxIsCtrlDown() || !wxIsShiftDown()) )
     {
         return MSWProcessMessage(wxmsg);
@@ -964,8 +1035,9 @@ void wxNotebook::OnNavigationKey(wxNavigationKeyEvent& event)
         //
         wxWindow * const parent = GetParent();
 
-        const bool isFromParent = event.GetEventObject() == parent;
-        const bool isFromSelf = event.GetEventObject() == this;
+        // the wxObject* casts are required to avoid MinGW GCC 2.95.3 ICE
+        const bool isFromParent = event.GetEventObject() == (wxObject*) parent;
+        const bool isFromSelf = event.GetEventObject() == (wxObject*) this;
 
         if ( isFromParent || isFromSelf )
         {
@@ -1044,7 +1116,7 @@ bool wxNotebook::DoDrawBackground(WXHDC hDC, wxWindow *child)
     wxUxThemeEngine::Get()->DrawThemeBackground
                             (
                                 theme,
-                                hDC,
+                                (HDC) hDC,
                                 9 /* TABP_PANE */,
                                 0,
                                 &rc,
@@ -1115,6 +1187,29 @@ bool wxNotebook::MSWPrintChild(WXHDC hDC, wxWindow *child)
     if ( !UseBgCol() && DoDrawBackground(hDC, child) )
         return true;
 
+    // If we're using a solid colour (for example if we've switched off
+    // theming for this notebook), paint it
+    if (UseBgCol())
+    {
+        wxRect r = GetPageSize();
+        if ( r.IsEmpty() )
+            return false;
+
+        RECT rc;
+        wxCopyRectToRECT(r, rc);
+
+        // map rect to the coords of the window we're drawing in
+        if ( child )
+            ::MapWindowPoints(GetHwnd(), GetHwndOf(child), (POINT *)&rc, 2);
+
+        wxBrush brush(GetBackgroundColour());
+        HBRUSH hbr = GetHbrushOf(brush);
+
+        ::FillRect((HDC) hDC, &rc, hbr);
+
+        return true;
+    }
+
     return wxNotebookBase::MSWPrintChild(hDC, child);
 }
 
@@ -1220,7 +1315,7 @@ bool wxNotebook::MSWOnNotify(int idCtrl, WXLPARAM lParam, WXLPARAM* result)
       return wxControl::MSWOnNotify(idCtrl, lParam, result);
   }
 
-  event.SetSelection(TabCtrl_GetCurSel(m_hwnd));
+  event.SetSelection(TabCtrl_GetCurSel(GetHwnd()));
   event.SetOldSelection(m_nSelection);
   event.SetEventObject(this);
   event.SetInt(idCtrl);
@@ -1230,79 +1325,4 @@ bool wxNotebook::MSWOnNotify(int idCtrl, WXLPARAM lParam, WXLPARAM* result)
   return processed;
 }
 
-#ifndef __WXWINCE__
-void wxNotebook::OnEraseBackground(wxEraseEvent& WXUNUSED(event))
-{
-    // do nothing here
-}
-
-void wxNotebook::OnPaint(wxPaintEvent& WXUNUSED(event))
-{
-    // Better painting behaviour, at the expense of system resources
-#if USE_NOTEBOOK_ANTIFLICKER
-    wxPaintDC dc(this);
-    wxMemoryDC memdc;
-    RECT rc;
-    ::GetClientRect(GetHwnd(), &rc);
-    wxBitmap bmp(rc.right, rc.bottom);
-    memdc.SelectObject(bmp);
-
-    // iterate over all child windows to find spin button
-    for ( HWND child = ::GetWindow(GetHwnd(), GW_CHILD);
-          child;
-          child = ::GetWindow(child, GW_HWNDNEXT) )
-    {
-        wxWindow *childWindow = wxFindWinFromHandle((WXHWND)child);
-
-        // see if it exists, if no wxWindow found then assume it's the spin btn
-        if ( !childWindow )
-        {
-            // subclass the spin button to override WM_ERASEBKGND
-            if ( !s_wndprocNotebookSpinBtn )
-                s_wndprocNotebookSpinBtn = (WXFARPROC)wxGetWindowProc(child);
-
-            wxSetWindowProc(child, wxNotebookSpinBtnWndProc);
-	    break;
-        }
-    }
-
-    HBRUSH hbr = (HBRUSH)m_hbrBackground;
-
-    // if there is no special brush just use the solid background colour
-    wxBrush brush;
-    if ( !hbr )
-    {
-        brush = wxBrush(GetBackgroundColour());
-        hbr = GetHbrushOf(brush);
-    }
-
-    ::FillRect(GetHdcOf(memdc), &rc, hbr);
-
-    MSWDefWindowProc(WM_PAINT, (WPARAM)memdc.GetHDC(), 0);
-
-    dc.Blit(0, 0, rc.right, rc.bottom, &memdc, 0, 0);
-#endif
-}
-#endif
-  // __WXWINCE__
-
-#if USE_NOTEBOOK_ANTIFLICKER
-// ---------------------------------------------------------------------------
-// window proc for spin button
-// ---------------------------------------------------------------------------
-
-LRESULT APIENTRY _EXPORT wxNotebookSpinBtnWndProc(HWND hwnd,
-                                                  UINT message,
-                                                  WPARAM wParam,
-                                                  LPARAM lParam)
-{
-    if ( message == WM_ERASEBKGND )
-        return 0;
-
-    return ::CallWindowProc(CASTWNDPROC s_wndprocNotebookSpinBtn, hwnd, message, wParam, lParam);
-}
-
-#endif
-    // USE_NOTEBOOK_ANTIFLICKER
-    
 #endif // wxUSE_NOTEBOOK
