@@ -4,7 +4,7 @@
 // Author:      Julian Smart
 // Modified by:
 // Created:     04/01/98
-// RCS-ID:      $Id: tbar95.cpp,v 1.150 2005/04/04 23:08:02 RD Exp $
+// RCS-ID:      $Id: tbar95.cpp,v 1.153 2005/05/27 09:14:58 JS Exp $
 // Copyright:   (c) Julian Smart
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -249,8 +249,14 @@ bool wxToolBar::Create(wxWindow *parent,
 #if wxUSE_UXTHEME
     if ( style & wxTB_FLAT )
     {
+        // Testing for an active theme appears to be unnecessary (see comments in patch 1204217).
+        // Disabling the test brings back separator lines.
+        // However, the separators can look ugly and distracting, especially between controls,
+        // so I'm restoring the test and removing the separators again - JACS
+#if 1
         wxUxThemeEngine *p = wxUxThemeEngine::Get();
         if ( !p || !p->IsThemeActive() )
+#endif            
         {
             DWORD dwToolbarStyle;
 
@@ -378,6 +384,7 @@ wxSize wxToolBar::DoGetBestSize() const
         sizeBest.y = size.cy;
     }
 
+    CacheBestSize(sizeBest);
     return sizeBest;
 }
 
