@@ -4,7 +4,7 @@
 // Author:      David Webster
 // Modified by:
 // Created:     10/10/99
-// RCS-ID:      $Id: menu.cpp,v 1.50 2005/03/17 23:45:20 VZ Exp $
+// RCS-ID:      $Id: menu.cpp,v 1.51 2005/04/27 01:19:41 DW Exp $
 // Copyright:   (c) David Webster
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -353,7 +353,7 @@ bool wxMenu::DoInsertOrAppend(
     {
         vError = ::WinGetLastError(vHabmain);
         sError = wxPMErrorToStr(vError);
-        wxLogError("Error inserting or appending a menuitem. Error: %s\n", sError.c_str());
+        wxLogError(wxT("Error inserting or appending a menuitem. Error: %s\n"), sError.c_str());
         wxLogLastError("Insert or AppendMenu");
         return FALSE;
     }
@@ -560,7 +560,7 @@ void wxMenu::SetTitle(
     {
         if (!rLabel.IsEmpty())
         {
-            if (!::WinSetWindowText(hMenu, rLabel.c_str()))
+            if (!::WinSetWindowText(hMenu, (PSZ)rLabel.c_str()))
             {
                 wxLogLastError("SetMenuTitle");
             }
@@ -581,7 +581,7 @@ void wxMenu::SetTitle(
             //
             // Modify the title
             //
-            if (!::WinSetWindowText(hMenu, rLabel.c_str()))
+            if (!::WinSetWindowText(hMenu, (PSZ)rLabel.c_str()))
             {
                 wxLogLastError("SetMenuTitle");
             }
@@ -790,7 +790,7 @@ WXHMENU wxMenuBar::Create()
             {
                 vError = ::WinGetLastError(vHabmain);
                 sError = wxPMErrorToStr(vError);
-                wxLogError("Error setting parent for submenu. Error: %s\n", sError.c_str());
+                wxLogError(wxT("Error setting parent for submenu. Error: %s\n"), sError.c_str());
                 return NULLHANDLE;
             }
 
@@ -798,7 +798,7 @@ WXHMENU wxMenuBar::Create()
             {
                 vError = ::WinGetLastError(vHabmain);
                 sError = wxPMErrorToStr(vError);
-                wxLogError("Error setting parent for submenu. Error: %s\n", sError.c_str());
+                wxLogError(wxT("Error setting parent for submenu. Error: %s\n"), sError.c_str());
                 return NULLHANDLE;
             }
 
@@ -809,7 +809,7 @@ WXHMENU wxMenuBar::Create()
             {
                 vError = ::WinGetLastError(vHabmain);
                 sError = wxPMErrorToStr(vError);
-                wxLogError("Error inserting or appending a menuitem. Error: %s\n", sError.c_str());
+                wxLogError(wxT("Error inserting or appending a menuitem. Error: %s\n"), sError.c_str());
                 return NULLHANDLE;
             }
         }
