@@ -4,7 +4,7 @@
 // Author:      David Webster
 // Modified by:
 // Created:     20.08.2003 (extracted from os2/utils.cpp)
-// RCS-ID:      $Id: utilsgui.cpp,v 1.8 2004/11/28 18:39:26 SN Exp $
+// RCS-ID:      $Id: utilsgui.cpp,v 1.10 2005/05/31 09:28:39 JS Exp $
 // Copyright:   (c) David Webster
 // License:     wxWindows licence
 ///////////////////////////////////////////////////////////////////////////////
@@ -519,7 +519,7 @@ wxString WXDLLEXPORT wxGetWindowText(
     if ( hWnd )
     {
 	long                lLen = ::WinQueryWindowTextLength((HWND)hWnd) + 1;
-	::WinQueryWindowText((HWND)hWnd, lLen, wxStringBuffer(vStr, lLen));
+	::WinQueryWindowText((HWND)hWnd, lLen, (PSZ)(wxChar*)wxStringBuffer(vStr, lLen));
     }
 
     return vStr;
@@ -536,7 +536,7 @@ wxString WXDLLEXPORT wxGetWindowClass(
 
 	for ( ;; )
 	{
-	    int                     nCount = ::WinQueryClassName((HWND)hWnd, nLen, wxStringBuffer(vStr, nLen));
+	    int                     nCount = ::WinQueryClassName((HWND)hWnd, nLen, (PSZ)(wxChar*)wxStringBuffer(vStr, nLen));
 
 	    if (nCount == nLen )
 	    {
@@ -939,7 +939,7 @@ wxBitmap wxDisableBitmap(
     int                             j;
 
     //
-    // Bitmap must be ina double-word alligned address so we may
+    // Bitmap must be in a double-word aligned address so we may
     // have some padding to worry about
     //
     if (nLineBoundary > 0)
