@@ -4,7 +4,7 @@
 // Author:      Julian Smart
 // Modified by:
 // Created:     2002-09-04
-// RCS-ID:      $Id: mainframe.cpp,v 1.18 2005/02/01 20:44:06 ABX Exp $
+// RCS-ID:      $Id: mainframe.cpp,v 1.20 2005/05/31 13:44:32 JS Exp $
 // Copyright:   (c) Julian Smart
 // Licence:
 /////////////////////////////////////////////////////////////////////////////
@@ -110,7 +110,7 @@ ctMainFrame::ctMainFrame(wxDocManager *manager, wxFrame *parent, wxWindowID id,
     m_findDialog = NULL;
 
     m_treeSplitterWindow = new wxSplitterWindow(this, wxID_ANY, wxDefaultPosition, wxSize(400, 300),
-        wxSP_3DSASH|wxSP_3DBORDER|wxNO_FULL_REPAINT_ON_RESIZE|wxCLIP_CHILDREN);
+        wxSP_3DSASH|wxSP_3DBORDER|wxNO_FULL_REPAINT_ON_RESIZE|wxCLIP_CHILDREN|wxSP_NO_XP_THEME);
 
     m_configTreeCtrl = new ctConfigTreeCtrl(m_treeSplitterWindow, wxID_ANY, wxDefaultPosition, wxDefaultSize,
         wxTR_HAS_BUTTONS|wxNO_BORDER|wxNO_FULL_REPAINT_ON_RESIZE|wxCLIP_CHILDREN);
@@ -421,7 +421,9 @@ void ctMainFrame::OnUpdateDisable(wxUpdateUIEvent& event)
 IMPLEMENT_CLASS(ctOutputWindow, wxPanel)
 
 BEGIN_EVENT_TABLE(ctOutputWindow, wxPanel)
+#if wxUSE_CLIPBOARD
     EVT_BUTTON(wxID_COPY, ctOutputWindow::OnCopyToClipboard)
+#endif // wxUSE_CLIPBOARD
     EVT_BUTTON(wxID_SAVE, ctOutputWindow::OnSaveText)
     EVT_BUTTON(ctID_REGENERATE, ctOutputWindow::OnRegenerate)
     EVT_UPDATE_UI(wxID_SAVE, ctOutputWindow::OnUpdateSaveText)
@@ -471,6 +473,7 @@ void ctOutputWindow::CreateWindows()
     SetSizer( item0 );
 }
 
+#if wxUSE_CLIPBOARD
 /// Copies the text to the clipboard.
 void ctOutputWindow::OnCopyToClipboard(wxCommandEvent& WXUNUSED(event))
 {
@@ -506,6 +509,7 @@ void ctOutputWindow::OnCopyToClipboard(wxCommandEvent& WXUNUSED(event))
         wxTheClipboard->Close();
     }
 }
+#endif // wxUSE_CLIPBOARD
 
 /// Sets the code in the text control.
 void ctOutputWindow::SetText(const wxString& text)
